<?php
/*
Plugin Name: Forex Factory Farsi Calendar
Description: نمایش زنده رویدادهای بازارهای فارکس، رمزارز، فلزات و انرژی
Version: 1.0
Author: فارکس فکتوری فارسی
Author URI: https://api.forexfactory.live/

*/


if (!defined('ABSPATH')) {
    exit;
}

// Enqueue scripts and styles only on pages containing FF table
function forex_factory_enqueue_scripts() {
    if ((is_page() || is_singular('post')) && has_shortcode(get_post()->post_content, 'forex_factory_live_calendar')) {
        wp_enqueue_style('forex-factory-style', plugin_dir_url(__FILE__) . 'assets/css/style.css');
        wp_enqueue_script('forex-factory-script', plugin_dir_url(__FILE__) . 'assets/js/script.js', array('jquery'), null, true);
    }
}
add_action('wp_enqueue_scripts', 'forex_factory_enqueue_scripts');

// Add admin settings page
add_action('admin_menu', function() {
    add_menu_page(
        'Forex Factory',            
        'فارکس فکتوری',         
        'manage_options',          
        'forex-factory',           
        'forex_factory_settings_page', 
        'dashicons-chart-line',     
        25                          
    );

    add_submenu_page(
        'forex-factory', 
        'Settings', 
        'Settings', 
        'manage_options', 
        'forex-factory',  
        'forex_factory_settings_page'
    );
});

function forex_factory_register_settings() {
    register_setting('forex_factory_settings', 'forex_factory_username');
    register_setting('forex_factory_settings', 'forex_factory_password');
    register_setting('forex_factory_settings', 'forex_factory_token');
}
add_action('admin_init', 'forex_factory_register_settings');

// Display settings page
function forex_factory_settings_page() {
    ?>
    <div class="forex-factory-wrap">
        <h1>تنظیمات فارکس فکتوری</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('forex_factory_settings');
            do_settings_sections('forex_factory_settings');
            ?>
            <table class="form-table">
                <tr>
                    <th><label for="forex_factory_username">نام کاربری</label></th>
                    <td><input type="text" id="forex_factory_username" name="forex_factory_username" value="<?php echo esc_attr(get_option('forex_factory_username', '')); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th><label for="forex_factory_password">رمز</label></th>
                    <td><input type="password" id="forex_factory_password" name="forex_factory_password" value="<?php echo esc_attr(get_option('forex_factory_password', '')); ?>" class="regular-text"></td>
                </tr>
            </table>
            <?php submit_button('ذخیره'); ?>
        </form>
        
        <div style="margin-top: 20px; padding: 10px; background: #f9f9f9; border: 1px solid #ddd; border-radius: 5px;">
            <p style="font-weight: bold; color: #333;">
                برای نمایش جدول رویدادهای اقتصادی، شورت کد 
                <code>[forex_factory_live_calendar]</code> 
                را در برگه موردنظر قرار دهید.
            </p>
        </div>
    </div>
    <?php
}

// Authenticate and get token
function forex_factory_authenticate() {
    $username = get_option('forex_factory_username');
    $password = get_option('forex_factory_password');
    
    if (!$username || !$password) {
        return false;
    }
    
    $response = wp_remote_post('https://api.forexfactory.live/api/auth/login', array(
        'body' => json_encode(array(
            'username' => $username,
            'password' => $password
        )),
        'headers' => array(
            'Content-Type' => 'application/json'
        )
    ));
    
    if (is_wp_error($response)) {
        return false;
    }
    
    $body = json_decode(wp_remote_retrieve_body($response), true);
    
    if (isset($body['token'])) {
        update_option('forex_factory_token', $body['token']);
        return $body['token'];
    }
    
    return false;
}

// get Forex Factory Data
function fetch_forex_factory_data() {
    $date = isset($_GET['date']) ? sanitize_text_field($_GET['date']) : date('Y-m-d');
    $api_url = 'https://api.forexfactory.live/api/v1/?date=' . $date;
    $token = get_option('forex_factory_token');
    
    if (!$token) {
        $token = forex_factory_authenticate();
        if (!$token) {
            return 'authentication_error'; 
        }
    }
    
    $response = wp_remote_get($api_url, array(
        'headers' => array(
            'Authorization' => 'Bearer ' . $token
        )
    ));
    
    if (is_wp_error($response)) {
        return 'authentication_error'; 
    }
    
    $body = wp_remote_retrieve_body($response);
    
    if (strpos($body, 'you have not a subscriptions') !== false) {
        return 'no_subscription';
    }
    
    $response_data = json_decode($body, true);
    if (isset($response_data['error']) && $response_data['error'] === 'Unauthorized') {
        return 'authentication_error';
    }
    
    return json_decode($body, true);
}

// Generate the Forex Factory Table
function generate_forex_factory_table() {
    $data = fetch_forex_factory_data();
    $current_date = isset($_GET['date']) ? sanitize_text_field($_GET['date']) : date('Y-m-d');
    
    ob_start();
    
    include plugin_dir_path(__FILE__) . 'templates/table.php';
    
    return ob_get_clean();
}
add_shortcode('forex_factory_live_calendar', 'generate_forex_factory_table');